Package: pdp
Type: Package
Title: Partial Dependence Plots
Version: 0.8.0
Authors@R: person(c("Brandon", "M."), family = "Greenwell", 
    email = "greenwell.brandon@gmail.com", role = c("aut", "cre"), 
    comment = c(ORCID = "0000-0002-8120-0084"))
Description: A general framework for constructing partial dependence (i.e.,
        marginal effect) plots from various types machine learning models
        in R.
License: GPL (>= 2)
URL: https://github.com/bgreenwell/pdp,
        http://bgreenwell.github.io/pdp/
BugReports: https://github.com/bgreenwell/pdp/issues
Depends: R (>= 3.6.0)
Suggests: adabag, AmesHousing, C50, caret, covr, Cubist, doParallel,
        dplyr, e1071, earth, gbm, gridExtra, ICEbox, ipred, keras,
        kernlab, magrittr, MASS, Matrix, mda, mlbench, nnet, party,
        partykit, randomForest, ranger, reticulate, rpart, tinytest,
        xgboost (>= 0.6-0), knitr, rmarkdown, vip
Imports: foreach, ggplot2 (>= 3.0.0), grDevices, lattice, methods,
        rlang (>= 0.3.0), stats, utils
LazyData: TRUE
RoxygenNote: 7.1.2
Encoding: UTF-8
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2022-05-11 14:16:57 UTC; bgreenwell
Author: Brandon M. Greenwell [aut, cre]
    (<https://orcid.org/0000-0002-8120-0084>)
Maintainer: Brandon M. Greenwell <greenwell.brandon@gmail.com>
Repository: CRAN
Date/Publication: 2022-05-11 23:20:06 UTC
Built: R 4.0.5; x86_64-w64-mingw32; 2022-05-12 07:00:43 UTC; windows
Archs: x64
