# Generated by roxygen2: do not edit by hand

S3method(autoplot,cice)
S3method(autoplot,ice)
S3method(autoplot,partial)
S3method(partial,default)
S3method(plotPartial,cice)
S3method(plotPartial,ice)
S3method(plotPartial,partial)
S3method(topPredictors,default)
S3method(topPredictors,train)
export("%>%")
export(grid.arrange)
export(partial)
export(plotPartial)
export(progress_progress)
export(topPredictors)
export(trellis.last.object)
importFrom(ggplot2,aes)
importFrom(ggplot2,autoplot)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_contour)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_rug)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,scale_fill_distiller)
importFrom(ggplot2,stat_summary)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(gridExtra,grid.arrange)
importFrom(lattice,dotplot)
importFrom(lattice,equal.count)
importFrom(lattice,levelplot)
importFrom(lattice,panel.dotplot)
importFrom(lattice,panel.levelplot)
importFrom(lattice,panel.lines)
importFrom(lattice,panel.loess)
importFrom(lattice,panel.rug)
importFrom(lattice,panel.xyplot)
importFrom(lattice,trellis.last.object)
importFrom(lattice,wireframe)
importFrom(lattice,xyplot)
importFrom(magrittr,"%>%")
useDynLib(pdp, .registration = TRUE)
